<?php
namespace Elementor;

class HDFAF_Widget extends Widget_Base {
	
	public function get_name() {
		return 'hdfaf-forms';
	}
	
	public function get_title() {
		return esc_html__('Hosting Domains Finder Affiliate Forms', 'hdfaf');
	}
	
	public function get_icon() {
		return 'eicon-form-horizontal';
	}
	
	public function get_categories() {
		return [ 'modeltheme-affiliate-widgets' ];
	}
	
	protected function register_controls() {

		$this->start_controls_section(
			'section_title',
			[
				'label' => esc_html__( 'General Options', 'hdfaf' ),
			]
		);
		
		$this->add_control(
			'affiliate_form_action_url',
			[
				'label' => esc_html__( 'Form Action url', 'hdfaf' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'' => esc_html__( 'Default', 'hdfaf' ),
					'https://www.namecheap.com/domains/registration/results/?'  => esc_html__( 'Namecheap', 'hdfaf' ),
					'https://www.bluehost.com/registration/?' => esc_html__( 'Bluehost', 'hdfaf' ),
					'https://www.godaddy.com/en-uk/domainsearch/find?' => esc_html__( 'GoDaddy', 'hdfaf' ),
				],
				'selectors' => [
					'{{WRAPPER}} .your-class' => 'border-style: {{VALUE}};',
				],
			]
		);
		$this->add_control(
	   		'placeholder',
	        [
	            'label' => esc_html__('Placeholder', 'hdfaf'),
	            'type' => Controls_Manager::TEXT,
	            'description ' => esc_html__('Register a domain name to start', 'hdfaf'),
	        ]
	    );
		$this->add_control(
	    	'domain_search',
	        [
	            'label' => esc_html__('Enable Domain Search?', 'hdfaf'),
	            'type' => Controls_Manager::SWITCHER,
	            'description ' => esc_html__('Enable/Disable Domain Search', 'hdfaf'),
	            'condition' => [
	              'affiliate_form_action_url' => 'https://www.bluehost.com/registration/?',
	            ],
	        ]
	    );
		$this->add_control(
			'submit_button_label',
			[
				'label' => esc_html__( 'Submit Button label', 'hdfaf' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter Submit button label', 'hdfaf' ),
			]
		);
		$this->add_control(
			'color',
			[
				'type' => \Elementor\Controls_Manager::COLOR,
				'label' => esc_html__( 'Choose custom background color', 'hdfaf' ),
			]
		);
		$this->add_control(
			'btn_color',
			[
				'type' => \Elementor\Controls_Manager::COLOR,
				'label' => esc_html__( 'Choose custom text color', 'hdfaf' ),
			]
		);
		$this->end_controls_section();

	}
	
	protected function render() {
        $settings 					= $this->get_settings_for_display();
        $affiliate_form_action_url 	= $settings['affiliate_form_action_url'];
        $submit_button_label 		= $settings['submit_button_label'];
        $color 						= $settings['color'];
        $placeholder 				= $settings['placeholder'];
        $domain_search 				= $settings['domain_search'];
        $btn_color 					= $settings['btn_color'];



		$shortcode_content = '';

        $shortcode_content .= do_shortcode('[hdfaf-builder-shortcode page_builder="elementor" 
        	affiliate_form_action_url="'.esc_attr($affiliate_form_action_url).'" 
        	color="'.esc_attr($color).'" 
        	placeholder="'.esc_html($placeholder).'" 
        	btn_color="'.esc_attr($btn_color).'" 
        	domain_search="'.esc_attr($domain_search).'" 
        	submit_button_label="'.esc_html($submit_button_label).'"]');

        echo  $shortcode_content;
	}
	
	protected function content_template() {

    }
}
